@@ -68,7 +68,6 @@ class PeerConnectionBase;
 class PeerInfo;
 class PeerList;
 class Piece;
-class Poll;
 class ProtocolExtension;
 class Rate;
 class ResourceManager;
@@ -79,20 +78,29 @@ class TrackerList;
 class TransferList;
 
 namespace net {
+
 class HttpGet;
 class HttpStack;
+class NetworkConfig;
+class NetworkManager;
+class Poll;
 class Resolver;
+
 } // namespace net
 
 namespace tracker {
+
 class DhtController;
 class Tracker;
+
 } // namespace tracker
 
 namespace utils {
+
 class Scheduler;
 class SchedulerEntry;
 class Thread;
+
 } // namespace utils
 
 } // namespace torrent
@@ -106,7 +114,18 @@ class Thread;
   #define LIBTORRENT_EXPORT
 #endif
 
-// TODO: Add the other torrent threads as namespaces.
+namespace torrent::config {
+
+torrent::net::NetworkConfig* network_config() LIBTORRENT_EXPORT;
+
+} // namespace torrent::config
+
+namespace torrent::runtime {
+
+torrent::net::NetworkManager* network_manager() LIBTORRENT_EXPORT;
+
+} // namespace torrent::runtime
+
 namespace torrent::this_thread {
 
 torrent::utils::Thread*   thread() LIBTORRENT_EXPORT;
@@ -119,12 +138,10 @@ void                      callback(void* target, std::function<void ()>&& fn);
 void                      cancel_callback(void* target);
 void                      cancel_callback_and_wait(void* target);
 
-Poll*                     poll() LIBTORRENT_EXPORT;
+net::Poll*                poll() LIBTORRENT_EXPORT;
 net::Resolver*            resolver() LIBTORRENT_EXPORT;
 utils::Scheduler*         scheduler() LIBTORRENT_EXPORT;
 
-// TODO: Add callbacks.
-
 [[gnu::weak]] void event_open(Event* event) LIBTORRENT_EXPORT;
 [[gnu::weak]] void event_open_and_count(Event* event) LIBTORRENT_EXPORT;
 [[gnu::weak]] void event_close_and_count(Event* event) LIBTORRENT_EXPORT;
@@ -144,6 +161,10 @@ namespace torrent::main_thread {
 torrent::utils::Thread* thread() LIBTORRENT_EXPORT;
 std::thread::id         thread_id() LIBTORRENT_EXPORT;
 
+void                    callback(void* target, std::function<void ()>&& fn);
+void                    cancel_callback(void* target);
+void                    cancel_callback_and_wait(void* target);
+
 uint32_t                hash_queue_size() LIBTORRENT_EXPORT;
 
 } // namespace torrent::main_thread
