@@ -37,7 +37,7 @@ public:
   bool                is_previously_created() const            { return m_flags & flag_previously_created; }
   bool                is_padding() const                       { return m_flags & flag_attr_padding; }
 
-  bool                has_flags(int flags)                     { return m_flags & flags; }
+  bool                has_flags(int flags) const               { return m_flags & flags; }
 
   void                set_flags(int flags);
   void                unset_flags(int flags);
@@ -74,7 +74,7 @@ public:
   // This might actually be wanted, as it would be nice to allow the
   // File to decide if it needs to try creating the underlying file or
   // not.
-  bool                prepare(int prot, int flags = 0);
+  bool                prepare(bool hashing, int prot, int flags);
 
   int                 protection() const                       { return m_protection; }
   void                set_protection(int prot)                 { m_protection = prot; }
@@ -104,7 +104,7 @@ private:
   File(const File&) = delete;
   File& operator=(const File&) = delete;
 
-  bool                resize_file();
+  bool                resize_file() const;
 
   int                 m_fd{-1};
   int                 m_protection{0};
@@ -141,12 +141,6 @@ File::unset_flags(int flags) {
   unset_flags_protected(flags & (flag_create_queued | flag_resize_queued | flag_fallocate | flag_prioritize_first | flag_prioritize_last| flag_attr_padding));
 }
 
-inline void
-File::set_completed_chunks(uint32_t v) {
-  if (!has_flags(flag_active) && v <= size_chunks())
-    m_completed = v;
-}
-
-}
+} // namespace torrent
 
 #endif
