@@ -52,8 +52,8 @@ class PeerConnectionBase;
 struct weighted_connection {
   weighted_connection(PeerConnectionBase* pcb, uint32_t w) : connection(pcb), weight(w) {}
 
-  bool operator == (const PeerConnectionBase* pcb) { return pcb == connection; }
-  bool operator != (const PeerConnectionBase* pcb) { return pcb != connection; }
+  bool operator == (const PeerConnectionBase* pcb) const { return pcb == connection; }
+  bool operator != (const PeerConnectionBase* pcb) const { return pcb != connection; }
 
   PeerConnectionBase* connection;
   uint32_t            weight;
@@ -62,9 +62,9 @@ struct weighted_connection {
 // TODO: Rename to choke_entry, create an new class called group entry?
 class group_entry {
 public:
-  typedef std::vector<weighted_connection> container_type;
+  using container_type = std::vector<weighted_connection>;
 
-  static const uint32_t unlimited = ~uint32_t();
+  static constexpr uint32_t unlimited = ~uint32_t();
 
   uint32_t            size_connections() const  { return m_queued.size() + m_unchoked.size(); }
 
@@ -102,8 +102,7 @@ private:
 };
 
 inline void group_entry::connection_unchoked(PeerConnectionBase* pcb) {
-  container_type::iterator itr = std::find_if(m_unchoked.begin(), m_unchoked.end(),
-                                              std::bind(&weighted_connection::operator==, std::placeholders::_1, pcb));
+  auto itr = std::find(m_unchoked.begin(), m_unchoked.end(), pcb);
 
   if (itr != m_unchoked.end()) throw internal_error("group_entry::connection_unchoked(pcb) failed.");
 
@@ -111,8 +110,7 @@ inline void group_entry::connection_unchoked(PeerConnectionBase* pcb) {
 }
 
 inline void group_entry::connection_queued(PeerConnectionBase* pcb) {
-  container_type::iterator itr = std::find_if(m_queued.begin(), m_queued.end(),
-                                              std::bind(&weighted_connection::operator==, std::placeholders::_1, pcb));
+  auto itr = std::find(m_queued.begin(), m_queued.end(), pcb);
 
   if (itr != m_queued.end()) throw internal_error("group_entry::connection_queued(pcb) failed.");
 
@@ -121,8 +119,7 @@ inline void group_entry::connection_queued(PeerConnectionBase* pcb) {
 
 inline void
 group_entry::connection_choked(PeerConnectionBase* pcb) {
-  container_type::iterator itr = std::find_if(m_unchoked.begin(), m_unchoked.end(),
-                                              std::bind(&weighted_connection::operator==, std::placeholders::_1, pcb));
+  auto itr = std::find(m_unchoked.begin(), m_unchoked.end(), pcb);
 
   if (itr == m_unchoked.end()) throw internal_error("group_entry::connection_choked(pcb) failed.");
 
@@ -132,8 +129,7 @@ group_entry::connection_choked(PeerConnectionBase* pcb) {
 
 inline void
 group_entry::connection_unqueued(PeerConnectionBase* pcb) {
-  container_type::iterator itr = std::find_if(m_queued.begin(), m_queued.end(),
-                                              std::bind(&weighted_connection::operator==, std::placeholders::_1, pcb));
+  auto itr = std::find(m_queued.begin(), m_queued.end(), pcb);
 
   if (itr == m_queued.end()) throw internal_error("group_entry::connection_unqueued(pcb) failed.");
 
@@ -141,6 +137,6 @@ group_entry::connection_unqueued(PeerConnectionBase* pcb) {
   m_queued.pop_back();
 }
 
-}
+} // namespace torrent
 
 #endif
